Getting Started
================
Faraday is designed to be simple and intuitive. The entire philosophy is based on 
amateur radio being an amazing learning tool as well as useful sandbox for experimentation.
Let's start at the bare basics, starting up the Faraday software

Starting Proxy
--------------
To start proxy simply double-click on the proxy.py script. You should see the python script running and server information present as you interact with it.